@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -15,6 +15,7 @@ import {
   IDevWorkspaceApi,
   IDevWorkspaceTemplateApi,
   IDockerConfigApi,
+  IEventApi,
   IKubeConfigApi,
   INamespaceApi,
   IServerConfigApi,
@@ -22,6 +23,9 @@ import {
 } from '../types';
 
 export class DevWorkspaceClient implements IDevWorkspaceClient {
+  get eventApi(): IEventApi {
+    throw new Error('Method not implemented.');
+  }
   get devworkspaceApi(): IDevWorkspaceApi {
     throw new Error('Method not implemented.');
   }
