@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { V220DevfileComponents } from '@devfile/api';
+import { V221DevfileComponents } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import * as k8s from '@kubernetes/client-node';
 import {
@@ -78,9 +78,19 @@ export class ServerConfigApiService implements IServerConfigApi {
     'containerBuildConfiguration' | 'disableContainerBuildCapabilities'
   > {
     const { devEnvironments } = cheCustomResource.spec;
+    const disableContainerBuildCapabilitiesEnvVar =
+      process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DISABLECONTAINERBUILDCAPABILITIES'];
+
+    // `defaultDisableContainerBuildCapabilities` is true if the env var is undefined or is not equal to 'false'
+    const defaultDisableContainerBuildCapabilities =
+      disableContainerBuildCapabilitiesEnvVar === undefined ||
+      disableContainerBuildCapabilitiesEnvVar.toLowerCase() !== 'false';
     return {
       containerBuildConfiguration: devEnvironments?.containerBuildConfiguration,
-      disableContainerBuildCapabilities: devEnvironments?.disableContainerBuildCapabilities,
+      disableContainerBuildCapabilities:
+        devEnvironments?.disableContainerBuildCapabilities !== undefined
+          ? devEnvironments?.disableContainerBuildCapabilities
+          : defaultDisableContainerBuildCapabilities,
     };
   }
 
@@ -89,15 +99,39 @@ export class ServerConfigApiService implements IServerConfigApi {
   }
 
   getDefaultEditor(cheCustomResource: CustomResourceDefinition): string | undefined {
-    return cheCustomResource.spec.devEnvironments?.defaultEditor;
+    return (
+      cheCustomResource.spec.devEnvironments?.defaultEditor ||
+      process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTEDITOR']
+    );
   }
 
-  getDefaultComponents(cheCustomResource: CustomResourceDefinition): V220DevfileComponents[] {
-    return cheCustomResource.spec.devEnvironments?.defaultComponents || [];
+  getDefaultComponents(cheCustomResource: CustomResourceDefinition): V221DevfileComponents[] {
+    if (cheCustomResource.spec.devEnvironments?.defaultComponents) {
+      return cheCustomResource.spec.devEnvironments.defaultComponents;
+    }
+
+    if (process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS']) {
+      try {
+        return JSON.parse(process.env['CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS']);
+      } catch (e) {
+        console.error(
+          `Unable to parse default components from environment variable CHE_DEFAULT_SPEC_DEVENVIRONMENTS_DEFAULTCOMPONENTS: ${e}`,
+        );
+      }
+    }
+
+    return [];
   }
 
   getOpenVSXURL(cheCustomResource: CustomResourceDefinition): string {
-    return cheCustomResource.spec.components?.pluginRegistry?.openVSXURL || '';
+    // Undefined and empty value are treated in a different ways:
+    //   - empty value forces to use embedded registry
+    //   - undefined value means that the default value should be used
+    if (cheCustomResource.spec.components?.pluginRegistry?.openVSXURL !== undefined) {
+      return cheCustomResource.spec.components.pluginRegistry.openVSXURL;
+    }
+
+    return process.env['CHE_DEFAULT_SPEC_COMPONENTS_PLUGINREGISTRY_OPENVSXURL'] || '';
   }
 
   getPvcStrategy(cheCustomResource: CustomResourceDefinition): string | undefined {
@@ -105,10 +139,15 @@ export class ServerConfigApiService implements IServerConfigApi {
   }
 
   getDashboardWarning(cheCustomResource: CustomResourceDefinition): string | undefined {
-    if (!cheCustomResource.spec.components?.dashboard?.headerMessage?.show) {
-      return undefined;
+    // Return the message if it is defined and the show flag is true
+    if (cheCustomResource.spec.components?.dashboard?.headerMessage?.text) {
+      return cheCustomResource.spec.components?.dashboard?.headerMessage?.show
+        ? cheCustomResource.spec.components.dashboard.headerMessage.text
+        : undefined;
     }
-    return cheCustomResource.spec.components?.dashboard?.headerMessage?.text;
+
+    // Return default message independently of the show flag.
+    return process.env['CHE_DEFAULT_SPEC_COMPONENTS_DASHBOARD_HEADERMESSAGE_TEXT'];
   }
 
   // getRunningWorkspacesLimit return the maximum number of running workspaces.
