@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,7 +11,7 @@
  */
 
 import { FastifyInstance } from 'fastify';
-import { ApplicationInfo, ClusterInfo } from '@eclipse-che/common';
+import { ApplicationId, ApplicationInfo, ClusterInfo } from '@eclipse-che/common';
 import { baseApiPath } from '../../constants/config';
 import { getSchema } from '../../services/helpers';
 
@@ -34,6 +34,7 @@ function buildApplicationInfo(): ClusterInfo {
   const applications: ApplicationInfo[] = [];
   if (clusterConsoleUrl) {
     applications.push({
+      id: ApplicationId.CLUSTER_CONSOLE,
       icon: clusterConsoleIcon,
       title: clusterConsoleTitle,
       url: clusterConsoleUrl,
