@@ -10,7 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { V220DevfileProjects, V220DevfileProjectsItemsGit } from '@devfile/api';
+import { V221DevfileProjects, V221DevfileProjectsItemsGit } from '@devfile/api';
 import common, { helpers } from '@eclipse-che/common';
 import { AlertVariant } from '@patternfly/react-core';
 import { isEqual } from 'lodash';
@@ -60,6 +60,7 @@ export type State = LoaderStepState & {
   newWorkspaceName?: string;
   shouldCreate: boolean; // should the loader create a workspace
   warning?: string; // the devWorkspace warning to show
+  restartFromError?: boolean; //
 };
 
 class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
@@ -157,7 +158,7 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
     this.props.onRestart();
   }
 
-  private updateCurrentDevfile(devfile: devfileApi.Devfile): void {
+  private updateCurrentDevfile(devfile: devfileApi.Devfile, appendSuffix?: boolean): void {
     const { factoryResolver, allWorkspaces, defaultDevfile } = this.props;
     const { factoryParams } = this.state;
     const { factoryId, policiesCreate, sourceUrl, storageType, remotes } = factoryParams;
@@ -185,9 +186,10 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
 
     // test the devfile name to decide if we need to append a suffix to is
     const nameConflict = allWorkspaces.some(w => devfile.metadata.name === w.name);
-    const appendSuffix = policiesCreate === 'perclick' || nameConflict;
+    const _appendSuffix =
+      appendSuffix === undefined ? policiesCreate === 'perclick' || nameConflict : appendSuffix;
 
-    const updatedDevfile = prepareDevfile(devfile, factoryId, storageType, appendSuffix);
+    const updatedDevfile = prepareDevfile(devfile, factoryId, storageType, _appendSuffix);
 
     this.setState({
       devfile: updatedDevfile,
@@ -227,7 +229,7 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
       return true;
     }
 
-    if (shouldCreate === false) {
+    if (!shouldCreate || this.state.lastError instanceof Error) {
       if (this.state.lastError instanceof Error) {
         throw this.state.lastError;
       }
@@ -247,17 +249,18 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
       if (_devfile === undefined) {
         throw new Error('Failed to resolve the devfile.');
       }
-      this.updateCurrentDevfile(_devfile);
+      if (!this.state.restartFromError) {
+        try {
+          await this.createWorkspaceFromDevfile(_devfile);
+        } catch (e) {
+          const errorMessage = common.helpers.errors.getMessage(e);
+          throw new CreateWorkspaceError(errorMessage);
+        }
+      }
+      this.updateCurrentDevfile(_devfile, false);
       return false;
     }
 
-    try {
-      await this.createWorkspaceFromDevfile(devfile);
-    } catch (e) {
-      const errorMessage = common.helpers.errors.getMessage(e);
-      throw new CreateWorkspaceError(errorMessage);
-    }
-
     // wait for the workspace creation to complete
     try {
       await this.waitForStepDone(TIMEOUT_TO_CREATE_SEC);
@@ -300,6 +303,9 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
       _devfile.metadata.generateName = devfile.metadata.generateName;
       this.updateCurrentDevfile(_devfile);
     }
+    this.setState({
+      restartFromError: true,
+    });
     this.clearStepError();
   }
 
@@ -390,7 +396,7 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
    * @param newRemotes The array of new Git remotes to add
    */
   private addRemotesToProject(
-    gitProject: V220DevfileProjectsItemsGit,
+    gitProject: V221DevfileProjectsItemsGit,
     checkoutRemote: GitRemote,
     newRemotes: GitRemote[],
   ) {
@@ -408,7 +414,7 @@ class StepApplyDevfile extends AbstractLoaderStep<Props, State> {
   /**
    * Returns the Git project to replace remotes for
    */
-  private getGitProjectForConfiguringRemotes(projects: V220DevfileProjects[] | undefined) {
+  private getGitProjectForConfiguringRemotes(projects: V221DevfileProjects[] | undefined) {
     if (!projects) {
       return undefined;
     }
