@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,29 +10,27 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { helpers } from '@eclipse-che/common';
+import { AlertVariant } from '@patternfly/react-core';
+import { isEqual } from 'lodash';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
-import { isEqual } from 'lodash';
-import { AlertVariant } from '@patternfly/react-core';
-import { helpers } from '@eclipse-che/common';
-import { AppState } from '../../../../../store';
-import { selectAllWorkspaces } from '../../../../../store/Workspaces/selectors';
-import * as WorkspaceStore from '../../../../../store/Workspaces';
-import WorkspaceLoaderPage from '../../../../../pages/Loader/Workspace';
-import { Workspace } from '../../../../../services/workspace-adapter';
-import { AlertItem, DevWorkspaceStatus, LoaderTab } from '../../../../../services/helpers/types';
-import { DisposableCollection } from '../../../../../services/helpers/disposable';
+import { LoaderPage } from '../../../../../pages/Loader';
+import { WorkspaceParams } from '../../../../../Routes/routes';
 import { delay } from '../../../../../services/helpers/delay';
+import { DisposableCollection } from '../../../../../services/helpers/disposable';
+import { AlertItem, DevWorkspaceStatus, LoaderTab } from '../../../../../services/helpers/types';
+import { Workspace } from '../../../../../services/workspace-adapter';
+import { AppState } from '../../../../../store';
+import * as WorkspaceStore from '../../../../../store/Workspaces';
+import { selectAllWorkspaces } from '../../../../../store/Workspaces/selectors';
+import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
 import { MIN_STEP_DURATION_MS, TIMEOUT_TO_STOP_SEC } from '../../../const';
 import findTargetWorkspace from '../../../findTargetWorkspace';
-import { AbstractLoaderStep, LoaderStepProps, LoaderStepState } from '../../../AbstractStep';
 
 export type Props = MappedProps &
   LoaderStepProps & {
-    matchParams: {
-      namespace: string;
-      workspaceName: string;
-    };
+    matchParams: WorkspaceParams;
   };
 export type State = LoaderStepState;
 
@@ -145,6 +143,10 @@ class StepInitialize extends AbstractLoaderStep<Props, State> {
   }
 
   protected findTargetWorkspace(props: Props): Workspace | undefined {
+    if (props.matchParams === undefined) {
+      return;
+    }
+
     return findTargetWorkspace(props.allWorkspaces, props.matchParams);
   }
 
@@ -181,12 +183,13 @@ class StepInitialize extends AbstractLoaderStep<Props, State> {
     const alertItem = this.getAlertItem(lastError);
 
     return (
-      <WorkspaceLoaderPage
+      <LoaderPage
         alertItem={alertItem}
         currentStepId={currentStepId}
         steps={steps}
         tabParam={tabParam}
         workspace={workspace}
+        onTabChange={tab => this.handleTabChange(tab)}
       />
     );
   }
