@@ -19,7 +19,6 @@ import ProjectsFormGroup from './Projects';
 import { constructWorkspace, Workspace } from '../../../services/workspace-adapter';
 import { cloneDeep } from 'lodash';
 import { DevWorkspaceStatus } from '../../../services/helpers/types';
-import { StorageTypeTitle } from '../../../services/storageTypes';
 
 type Props = {
   onSave: (workspace: Workspace) => Promise<void>;
@@ -111,7 +110,7 @@ export class OverviewTab extends React.Component<Props, State> {
             <InfrastructureNamespaceFormGroup namespace={namespace} />
             <StorageTypeFormGroup
               readonly={isDeprecated || workspace.status === DevWorkspaceStatus.TERMINATING}
-              storageType={StorageTypeTitle[storageType as che.WorkspaceStorageType] || storageType}
+              storageType={storageType}
               onSave={_storageType => this.handleStorageSave(_storageType)}
             />
             <ProjectsFormGroup projects={projects} />
