@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -34,6 +34,6 @@ export async function getYamlResolver(
       links: [],
     };
   } catch (e) {
-    throw `Failed to fetch yaml resolver'. ${helpers.errors.getMessage(e)}`;
+    throw new Error(`Failed to fetch yaml resolver'. ${helpers.errors.getMessage(e)}`);
   }
 }
