@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -98,15 +98,32 @@ export function toHref(history: History, location: Location): string {
   return history.createHref(location);
 }
 
-const oauthParams = ['state', 'session_state', 'code'];
+const oauthParams = ['state', 'session', 'session_state', 'code'];
 /**
  * Removes oauth params.
  */
-export function sanitizeLocation(location: Location, removeParams: string[] = []): Location {
+export function sanitizeLocation<T extends { search: string; pathname: string } = Location>(
+  location: T,
+  removeParams: string[] = [],
+): T {
   const toRemove = [...oauthParams, ...removeParams];
   // clear search params
   if (location.search) {
     const searchParams = new window.URLSearchParams(location.search);
+
+    // sanitize the URL inside searchParams
+    const targetParam = 'url';
+    let targetValue = searchParams.get(targetParam);
+    if (targetValue !== null) {
+      toRemove.forEach(param => {
+        const re = new RegExp('[&|?]' + param + '=[^&]+', 'i');
+        if (targetValue) {
+          targetValue = targetValue.replace(re, '');
+        }
+      });
+      searchParams.set(targetParam, targetValue);
+    }
+
     toRemove.forEach(val => searchParams.delete(val));
     location.search = '?' + searchParams.toString();
   }
