@@ -14,7 +14,7 @@ import {
   V1alpha2DevWorkspaceSpecTemplateComponents,
   V1alpha2DevWorkspaceTemplateSpec,
   V1alpha2DevWorkspaceTemplateSpecComponents,
-  V220DevfileComponentsItemsContainer,
+  V221DevfileComponentsItemsContainer,
 } from '@devfile/api';
 import { api } from '@eclipse-che/common';
 import { WorkspacesDefaultPlugins } from 'dashboard-frontend/src/store/Plugins/devWorkspacePlugins';
@@ -45,6 +45,7 @@ import {
   devWorkspaceVersion,
 } from './converters';
 import { DevWorkspaceDefaultPluginsHandler } from './DevWorkspaceDefaultPluginsHandler';
+import { DevWorkspacePlugin } from '../../devfileApi/devWorkspace';
 
 const COMPONENT_UPDATE_POLICY = 'che.eclipse.org/components-update-policy';
 const REGISTRY_URL = 'che.eclipse.org/plugin-registry-url';
@@ -55,9 +56,11 @@ export const DEVWORKSPACE_DEBUG_START_ANNOTATION = 'controller.devfile.io/debug-
 
 export const DEVWORKSPACE_DEVFILE_SOURCE = 'che.eclipse.org/devfile-source';
 
+export const DEVWORKSPACE_DEVFILE = 'che.eclipse.org/devfile';
+
 export const DEVWORKSPACE_METADATA_ANNOTATION = 'dw.metadata.annotations';
 
-export interface ICheEditorOverrideContainer extends V220DevfileComponentsItemsContainer {
+export interface ICheEditorOverrideContainer extends V221DevfileComponentsItemsContainer {
   name: string;
 }
 export interface ICheEditorYaml {
@@ -144,7 +147,9 @@ export class DevWorkspaceClient extends WorkspaceClient {
     devWorkspaceResource: devfileApi.DevWorkspace,
     editorId: string | undefined,
   ): Promise<{ headers: DwApi.Headers; devWorkspace: devfileApi.DevWorkspace }> {
-    devWorkspaceResource.spec.routingClass = 'che';
+    if (!devWorkspaceResource.spec.routingClass) {
+      devWorkspaceResource.spec.routingClass = 'che';
+    }
     devWorkspaceResource.spec.started = false;
     devWorkspaceResource.metadata.namespace = defaultNamespace;
 
@@ -668,7 +673,7 @@ export class DevWorkspaceClient extends WorkspaceClient {
     }
     const contributions = workspace.spec.contributions.filter(
       contribution => contribution.name !== pluginName,
-    );
+    ) as DevWorkspacePlugin[];
     contributions.push({
       name: pluginName,
       kubernetes: {
