@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -28,6 +28,8 @@ import { getYamlResolver } from '../../services/dashboard-backend-client/yamlRes
 import { DEFAULT_REGISTRY } from '../DevfileRegistries';
 import { isOAuthResponse } from '../../services/oauth';
 import { AUTHORIZED, SanityCheckAction } from '../sanityCheckMiddleware';
+import { CHE_EDITOR_YAML_PATH } from '../../services/workspace-client';
+import { FactoryParams } from '../../containers/Loader/buildFactoryParams';
 
 const WorkspaceClient = container.get(CheWorkspaceClient);
 
@@ -83,7 +85,7 @@ export type KnownAction =
 export type ActionCreators = {
   requestFactoryResolver: (
     location: string,
-    overrideParams?: { [params: string]: string },
+    factoryParams: Partial<FactoryParams>,
   ) => AppThunk<KnownAction, Promise<void>>;
 };
 
@@ -127,7 +129,7 @@ export const actionCreators: ActionCreators = {
   requestFactoryResolver:
     (
       location: string,
-      overrideParams?: { [params: string]: string },
+      factoryParams: Partial<FactoryParams> = {},
     ): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch, getState): Promise<void> => {
       await dispatch({ type: 'REQUEST_FACTORY_RESOLVER', check: AUTHORIZED });
@@ -135,9 +137,14 @@ export const actionCreators: ActionCreators = {
       const namespace = selectDefaultNamespace(state).name;
       const optionalFilesContent = {};
 
+      const overrideParams = factoryParams
+        ? Object.assign({}, factoryParams.overrides, {
+            error_code: factoryParams?.errorCode,
+          })
+        : undefined;
+
       try {
         let data: FactoryResolver;
-
         if (location.includes(DEFAULT_REGISTRY) && location.endsWith('.yaml')) {
           data = await getYamlResolver(namespace, location);
         } else {
@@ -145,18 +152,9 @@ export const actionCreators: ActionCreators = {
             location,
             overrideParams,
           );
-          // now, grab content of optional files if they're there
-          const vscodeExtensionsJson = await grabLink(data.links, '.vscode/extensions.json');
-          if (vscodeExtensionsJson) {
-            optionalFilesContent['.vscode/extensions.json'] = vscodeExtensionsJson;
-          }
-          const cheTheiaPlugins = await grabLink(data.links, '.che/che-theia-plugins.yaml');
-          if (cheTheiaPlugins) {
-            optionalFilesContent['.che/che-theia-plugins.yaml'] = cheTheiaPlugins;
-          }
-          const cheEditor = await grabLink(data.links, '.che/che-editor.yaml');
+          const cheEditor = await grabLink(data.links, CHE_EDITOR_YAML_PATH);
           if (cheEditor) {
-            optionalFilesContent['.che/che-editor.yaml'] = cheEditor;
+            optionalFilesContent[CHE_EDITOR_YAML_PATH] = cheEditor;
           }
         }
         if (!data.devfile) {
@@ -173,6 +171,7 @@ export const actionCreators: ActionCreators = {
             location,
             defaultComponents,
             namespace,
+            factoryParams,
           );
         } else {
           const devfileV1 = normalizeDevfileV1(
@@ -185,6 +184,7 @@ export const actionCreators: ActionCreators = {
             location,
             defaultComponents,
             namespace,
+            factoryParams,
           );
         }
         const converted: ConvertedState = {
