@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -16,8 +16,7 @@ import { createObject } from '../helpers';
 import devfileApi from '../../services/devfileApi';
 import { Workspace } from '../../services/workspace-adapter';
 import * as DevWorkspacesStore from './devWorkspaces';
-import common from '@eclipse-che/common';
-import OAuthService, { isOAuthResponse } from '../../services/oauth';
+import { FactoryParams } from '../../containers/Loader/buildFactoryParams';
 
 // This state defines the type of data maintained in the Redux store.
 export interface State {
@@ -109,7 +108,7 @@ export type ActionCreators = {
   updateWorkspace: (workspace: Workspace) => AppThunk<KnownAction, Promise<void>>;
   createWorkspaceFromDevfile: (
     devfile: devfileApi.Devfile,
-    attributes: { [key: string]: string },
+    attributes: Partial<FactoryParams>,
     optionalFilesContent?: {
       [fileName: string]: string;
     },
@@ -122,7 +121,6 @@ export type ActionCreators = {
   clearWorkspaceQualifiedName: () => AppThunk<ClearWorkspaceQualifiedName>;
   setWorkspaceUID: (workspaceUID: string) => AppThunk<SetWorkspaceUID>;
   clearWorkspaceUID: () => AppThunk<ClearWorkspaceUID>;
-  deleteWorkspaceLogs: (workspace: Workspace) => AppThunk<DeleteWorkspaceLogsAction>;
 };
 
 export const actionCreators: ActionCreators = {
@@ -157,29 +155,6 @@ export const actionCreators: ActionCreators = {
     (workspace: Workspace, params?: ResourceQueryParams): AppThunk<KnownAction, Promise<void>> =>
     async (dispatch): Promise<void> => {
       dispatch({ type: 'REQUEST_WORKSPACES' });
-      try {
-        await OAuthService.refreshTokenIfNeeded(workspace);
-      } catch (e) {
-        if (common.helpers.errors.includesAxiosResponse(e)) {
-          const response = e.response;
-          if (response.status === 401 && isOAuthResponse(response.data)) {
-            // build redirect URL
-            const redirectUrl = new URL(
-              'dashboard/w',
-              window.location.protocol + '//' + window.location.host,
-            );
-            redirectUrl.searchParams.set(
-              'params',
-              `{"namespace":"${workspace.namespace}","workspace":"${workspace.name}"}`,
-            );
-            OAuthService.openOAuthPage(
-              response.data.attributes.oauth_authentication_url,
-              redirectUrl.toString(),
-            );
-            return;
-          }
-        }
-      }
       const debugWorkspace = params && params['debug-workspace-start'];
       await dispatch(
         DevWorkspacesStore.actionCreators.startWorkspace(workspace.ref, debugWorkspace),
@@ -240,26 +215,19 @@ export const actionCreators: ActionCreators = {
   createWorkspaceFromDevfile:
     (
       devfile: devfileApi.Devfile,
-      attributes: { [key: string]: string },
+      attributes: Partial<FactoryParams>,
       optionalFilesContent?: {
         [fileName: string]: string;
       },
     ): AppThunk<KnownAction, Promise<void>> =>
-    async (dispatch, getState): Promise<void> => {
+    async (dispatch): Promise<void> => {
       dispatch({ type: 'REQUEST_WORKSPACES' });
       try {
-        const state = getState();
-        const pluginRegistryUrl =
-          state.workspacesSettings.settings['cheWorkspacePluginRegistryUrl'];
-        const pluginRegistryInternalUrl =
-          state.workspacesSettings.settings['cheWorkspacePluginRegistryInternalUrl'];
         await dispatch(
           DevWorkspacesStore.actionCreators.createWorkspaceFromDevfile(
             devfile,
-            optionalFilesContent || {},
-            pluginRegistryUrl,
-            pluginRegistryInternalUrl,
             attributes,
+            optionalFilesContent || {},
           ),
         );
         dispatch({ type: 'ADD_WORKSPACE' });
@@ -295,12 +263,6 @@ export const actionCreators: ActionCreators = {
   clearWorkspaceUID: (): AppThunk<ClearWorkspaceUID> => dispatch => {
     dispatch({ type: 'CLEAR_WORKSPACE_UID' });
   },
-
-  deleteWorkspaceLogs:
-    (workspace: Workspace): AppThunk<KnownAction> =>
-    (dispatch): void => {
-      dispatch(DevWorkspacesStore.actionCreators.deleteWorkspaceLogs(workspace.uid));
-    },
 };
 
 const unloadedState: State = {
